==> tecfy_corev2_package-1.1.84.tar.gz: lib/views/components/dashboard/dashboard_url_component.dart <==
import 'package:flutter/material.dart';
// import 'package:flutter_html/flutter_html.dart';
import 'package:flutter_widget_from_html/flutter_widget_from_html.dart';
import 'package:tecfy_basic_package/tecfy_basic_package.dart';
import 'package:tecfy_corev2_package/models/home/dashboard_url.dart';
import 'package:tecfy_corev2_package/tecfy_core_client_package.dart';
// import 'dart:html' as html;
// import 'dart:ui_web' as ui;

class DashboardUrlComponenet extends StatefulWidget {
  final DashboardUrl type;
  DashboardUrlComponenet(this.type);
  @override
  _DashboardChartComponenetState createState() =>
      _DashboardChartComponenetState();
}

class _DashboardChartComponenetState extends State<DashboardUrlComponenet> {
  // final html.IFrameElement _iFrameElement = html.IFrameElement();
  // @override
  // void initState() {
  //   print("this is token ${ConfigService.token}");
  //   print("this is full url ${widget.type.url! + ConfigService.token}");
  //   _iFrameElement.src = widget.type.url! + ConfigService.token;
  //   _iFrameElement.style.border = 'none';
  //   _iFrameElement.width = '100%';
  //   _iFrameElement.height = '100%';
  //   ui.platformViewRegistry.registerViewFactory(
  //     'iframeElement',
  //     (int viewId) => _iFrameElement,
  //   );
  //   super.initState();
  // }
  // final Widget _iframeWidget = HtmlElementView(
  //   viewType: 'iframeElement',
  //   key: UniqueKey(),
  // );

  _onItemTab(type) async {
    if (type.onClick == null || type.onClick.isEmpty) return;
    if (type.onClick.startsWith('EntityList:')) {
      AppNavigator.navigateTo(context,
          () => EntityListPage(type.onClick.replaceAll('EntityList:', '')));
      return;
    }
    if (type.onClick.startsWith('Report:')) {
      var result =
          await TecfyBasicApp.apiService.httpGetDynamic('Report/GetList');
      var reportName = type.onClick.replaceAll('Report:', '');
      var report = result.data
          .firstWhere((s) => s['dbName'] == reportName, orElse: () => null);
      if (report == null) return;
      ReportDataService.onOpenReport(context, report);
      return;
    }
  }

  // Future<dynamic> getData() async {
  //   var type = widget.type;
  //   if (type.value != null) return type.value;
  //   if (type.value == -1) return null;
  //   type.value = -1;
  //   var result =
  //       await TecfyBasicApp.apiService.httpGetDynamic('Dashboard/GetData/${type.dbName}');
  //   if (!result.success) {
  //     result.data = jsonDecode(
  //         ConfigService.getValueString('DashboardType${type.dbName}'));
  //     result.success = result.data != null;
  //   }
  //   if (result.success) {
  //     ConfigService.setValueString(
  //         'DashboardType${type.dbName}', jsonEncode(result.data));
  //     //return result.data;
  //     type.value = result.data;
  //   }
  //   setState(() {});
  //   return type.value;
  // }

  _getWidth() {
    var fullwidth = LayoutService.getWidth(context);
    if (LayoutService.isMobile(context)) {
      return fullwidth - 20;
    }
    fullwidth -= (ThemeService.menuWidth + 40);
    if (fullwidth > ThemeService.containerWidth) {
      fullwidth = ThemeService.containerWidth - 40;
    }
    if (fullwidth < 600) {
      return fullwidth;
    }
    return fullwidth / 2;
  }

  double getWidthEx() {
    if (widget.type.width == null || !((widget.type.width ?? 0) > 0)) {
      if (widget.type.height == null) {
        return (ThemeService.containerWidth / 12) * (widget.type.size ?? 1);
      } else {
        return widget.type.height as double;
      }
    }
    return widget.type.width as double;
  }

  double getHeightEx() {
    if (widget.type.height == null || !((widget.type.height ?? 0) > 0)) {
      if (widget.type.width == null) {
        return (ThemeService.containerWidth / 12) * (widget.type.size ?? 1);
      } else {
        return widget.type.width as double;
      }
    }
    return widget.type.height as double;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: EdgeInsets.all(10),
      //using iFrame Flutter
      // child: _iframeWidget,
      child: HtmlWidget(''' 
        <iframe width="${getWidthEx()}" height="${getHeightEx()}" src="${widget.type.url! + ConfigService.token}" frameborder="0"></iframe> 
      '''),
      height: getHeightEx(),
      width: getWidthEx(),
    );
  }
}

==> tecfy_corev2_package-1.1.99.tar.gz: lib/views/components/dashboard/dashboard_url_component.dart <==
import 'package:flutter/material.dart';
// import 'package:flutter_html/flutter_html.dart';
import 'package:flutter_widget_from_html/flutter_widget_from_html.dart';
import 'package:tecfy_basic_package/tecfy_basic_package.dart';
import 'package:tecfy_corev2_package/models/home/dashboard_url.dart';
import 'package:tecfy_corev2_package/services/config.dart';
import 'package:tecfy_corev2_package/tecfy_core_client_package.dart';
// import 'dart:html' as html;
// import 'dart:ui_web' as ui;

class DashboardUrlComponenet extends StatefulWidget {
  final DashboardUrl type;
  DashboardUrlComponenet(this.type);
  @override
  _DashboardChartComponenetState createState() =>
      _DashboardChartComponenetState();
}

class _DashboardChartComponenetState extends State<DashboardUrlComponenet> {
  // final html.IFrameElement _iFrameElement = html.IFrameElement();
  // @override
  // void initState() {
  //   print("this is token ${ConfigService.token}");
  //   print("this is full url ${widget.type.url! + ConfigService.token}");
  //   _iFrameElement.src = widget.type.url! + ConfigService.token;
  //   _iFrameElement.style.border = 'none';
  //   _iFrameElement.width = '100%';
  //   _iFrameElement.height = '100%';
  //   ui.platformViewRegistry.registerViewFactory(
  //     'iframeElement',
  //     (int viewId) => _iFrameElement,
  //   );
  //   super.initState();
  // }
  // final Widget _iframeWidget = HtmlElementView(
  //   viewType: 'iframeElement',
  //   key: UniqueKey(),
  // );

  _onItemTab(type) async {
    if (type.onClick == null || type.onClick.isEmpty) return;
    if (type.onClick.startsWith('EntityList:')) {
      AppNavigator.navigateTo(context,
          () => EntityListPage(type.onClick.replaceAll('EntityList:', '')));
      return;
    }
    if (type.onClick.startsWith('Report:')) {
      var result =
          await TecfyBasicApp.apiService.httpGetDynamic('Report/GetList');
      var reportName = type.onClick.replaceAll('Report:', '');
      var report = result.data
          .firstWhere((s) => s['dbName'] == reportName, orElse: () => null);
      if (report == null) return;
      ReportDataService.onOpenReport(context, report);
      return;
    }
  }

  // Future<dynamic> getData() async {
  //   var type = widget.type;
  //   if (type.value != null) return type.value;
  //   if (type.value == -1) return null;
  //   type.value = -1;
  //   var result =
  //       await TecfyBasicApp.apiService.httpGetDynamic('Dashboard/GetData/${type.dbName}');
  //   if (!result.success) {
  //     result.data = jsonDecode(
  //         ConfigService.getValueString('DashboardType${type.dbName}'));
  //     result.success = result.data != null;
  //   }
  //   if (result.success) {
  //     ConfigService.setValueString(
  //         'DashboardType${type.dbName}', jsonEncode(result.data));
  //     //return result.data;
  //     type.value = result.data;
  //   }
  //   setState(() {});
  //   return type.value;
  // }

  _getWidth() {
    var fullwidth = LayoutService.getWidth(context);
    if (LayoutService.isMobile(context)) {
      return fullwidth - 20;
    }
    fullwidth -= (ThemeService.menuWidth + 40);
    if (fullwidth > ThemeService.containerWidth) {
      fullwidth = ThemeService.containerWidth - 40;
    }
    if (fullwidth < 600) {
      return fullwidth;
    }
    return fullwidth / 2;
  }

  double getWidthEx() {
    if (widget.type.width == null || !((widget.type.width ?? 0) > 0)) {
      if (widget.type.height == null) {
        return (ThemeService.containerWidth / 12) * (widget.type.size ?? 1);
      } else {
        return widget.type.height?.toDouble() ?? 0.0;
      }
    }
    return widget.type.width?.toDouble() ?? 0.0;
  }

  double getHeightEx() {
    if (widget.type.height == null || !((widget.type.height ?? 0) > 0)) {
      if (widget.type.width == null) {
        return (ThemeService.containerWidth / 12) * (widget.type.size ?? 1);
      } else {
        return widget.type.width?.toDouble() ?? 0.0;
      }
    }
    return widget.type.height?.toDouble() ?? 0.0;
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: EdgeInsets.all(10),
      decoration: BoxDecoration(
          border: Border.all(color: Colors.grey.withOpacity(0.5))),
      //using iFrame Flutter
      // child: _iframeWidget,
      child: HtmlWidget(''' 
        <iframe width="${getWidthEx()}" height="${getHeightEx()}" src="${getUrlEx(widget.type.url! + ConfigService.token)}" frameborder="0"></iframe> 
      '''),
      height: getHeightEx(),
      width: getWidthEx(),
    );
  }
}
